# coding: utf-8

##
# google glass api 基础类
module GoogleSdk

  # 用户认证基类
  module OAuth

    def self.included(base)
      base.extend ClassMethods
      base.instance_variable_set "@default_options", {}
      base.send :google_uri, "https://accounts.google.com"
      base.send :attr_accessor, :default_options
    end

    module ClassMethods

      def default_options
        @default_options
      end

      def client_id(value)
        default_options[:params][:client_id] = value
      end

      def client_secret(value)
        default_options[:params][:client_secret] = value
      end

      def scope(value)
        default_options[:params][:scope] = value.join('+')
      end

      def access_type(value)
        default_options[:params][:access_type] = value
      end

      def approval_prompt(value)
        default_options[:params][:approval_prompt] = value
      end

      def redirect_uri(value)
        default_options[:params][:redirect_uri] = value
      end

      def login_url
        params = []
        default_options[:params].each {|key, value| params << "#{key}=#{value}"}
        return "#{default_options[:google_uri]}/o/oauth2/auth?#{params.join("&")}"
      end

      def user_token(code)
        RestClient.post "#{default_options[:google_uri]}/o/oauth2/token", {
            code: code,
            client_id: default_options[:params][:client_id],
            client_secret: default_options[:params][:client_secret],
            redirect_uri: default_options[:params][:redirect_uri],
            grant_type: 'authorization_code'
        }
      end


    end
  end
end